<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko_KR">
<context>
    <name>CompletingEdit</name>
    <message>
        <source>Jump to PDF</source>
        <translation>PDF의 여기로 가기</translation>
    </message>
    <message>
        <source>No suggestions</source>
        <translation>제안항목 없음</translation>
    </message>
    <message>
        <source>Ignore word</source>
        <translation>이 단어 무시</translation>
    </message>
</context>
<context>
    <name>ConfirmDelete</name>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>Unable to delete</source>
        <translation>삭제할 수 없음</translation>
    </message>
    <message>
        <source>Some of the auxiliary files could not be removed. Perhaps you don&apos;t have permission to delete them.</source>
        <translation>일부 부수파일을 삭제할 수 없습니다. 권한을 확인하세요.</translation>
    </message>
    <message>
        <source>Confirm file deletion</source>
        <translation>파일 삭제 확인</translation>
    </message>
    <message>
        <source>Auxiliary files to be deleted:</source>
        <translation>삭제할 부수파일:</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>모두 선택</translation>
    </message>
    <message>
        <source>Select None</source>
        <translation>선택 해제</translation>
    </message>
    <message>
        <source>Toggle</source>
        <translation>맞바꾸기</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Find</source>
        <translation>찾기</translation>
    </message>
    <message>
        <source>Find:</source>
        <translation>찾을 문자열:</translation>
    </message>
    <message>
        <source>&amp;Wrap around</source>
        <translation>끝까지 가면 처음부터(&amp;w)</translation>
    </message>
    <message>
        <source>Find &amp;backwards</source>
        <translation>뒤로 찾기(&amp;b)</translation>
    </message>
    <message>
        <source>Search within &amp;selection</source>
        <translation>선택영역 내에서 찾기(&amp;s)</translation>
    </message>
    <message>
        <source>Find &amp;all occurrences</source>
        <translation>한꺼번에 찾기(&amp;a)</translation>
    </message>
    <message>
        <source>Search all &amp;open files</source>
        <translation>열린 파일 다 찾기(&amp;o)</translation>
    </message>
    <message>
        <source>&amp;Case sensitive</source>
        <translation>대소문자 구분(&amp;c)</translation>
    </message>
    <message>
        <source>W&amp;hole words</source>
        <translation>전체가 맞는 단어만(&amp;h)</translation>
    </message>
    <message>
        <source>&amp;Regular expression</source>
        <translation>정규표현식(&amp;r)</translation>
    </message>
    <message>
        <source>No recent search strings</source>
        <translation>최근 찾기 문자열 없음</translation>
    </message>
    <message>
        <source>(invalid)</source>
        <translation>(유효하지 않음)</translation>
    </message>
</context>
<context>
    <name>HardWrapDialog</name>
    <message>
        <source>Hard Wrap</source>
        <translation>자동 줄 바꿈</translation>
    </message>
    <message>
        <source>Wrap lines to:</source>
        <translation>줄 바꿈 기준:</translation>
    </message>
    <message>
        <source>Current window size</source>
        <translation>현재 창 크기</translation>
    </message>
    <message>
        <source>Line length:</source>
        <translation>문자 갯수:</translation>
    </message>
    <message>
        <source>Re-wrap paragraphs</source>
        <translation>문단 재정렬</translation>
    </message>
    <message>
        <source>Unwrap</source>
        <translation>줄 바꿈 취소</translation>
    </message>
</context>
<context>
    <name>PDFDocument</name>
    <message>
        <source>Open Recent</source>
        <translation>최근 문서 열기</translation>
    </message>
    <message>
        <source>Failed to load file &quot;%1&quot;; perhaps it is not a valid PDF document.</source>
        <translation>&quot;%1&quot; 파일을 열 수 없습니다. 유효한 PDF 문서가 아닐 수 있습니다.</translation>
    </message>
    <message>
        <source>No SyncTeX data available</source>
        <translation>SyncTeX 데이터가 없습니다</translation>
    </message>
    <message>
        <source>SyncTeX: &quot;%1&quot;</source>
        <translation></translation>
    </message>
    <message>
        <source>%1[*] - %2</source>
        <translation></translation>
    </message>
    <message>
        <source>page %1 of %2</source>
        <translation>%2쪽 중 %1쪽</translation>
    </message>
    <message>
        <source>%1%</source>
        <translation></translation>
    </message>
    <message>
        <source>untitled.pdf[*]</source>
        <translation></translation>
    </message>
    <message>
        <source>Help</source>
        <translation>도움말</translation>
    </message>
    <message>
        <source>File</source>
        <translation>파일</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>편집</translation>
    </message>
    <message>
        <source>View</source>
        <translation>보기</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>창</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>보기</translation>
    </message>
    <message>
        <source>Typeset</source>
        <translation>조판</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>찾기</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>툴바</translation>
    </message>
    <message>
        <source>About TeXworks...</source>
        <translation>TeXworks에 대하여...</translation>
    </message>
    <message>
        <source>First Page</source>
        <translation>첫 쪽</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>이전 쪽</translation>
    </message>
    <message>
        <source>Ctrl+PgUp</source>
        <comment>shortcut key name, do not translate</comment>
        <translation></translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>다음 쪽</translation>
    </message>
    <message>
        <source>Ctrl+PgDown</source>
        <comment>shortcut key name, do not translate</comment>
        <translation></translation>
    </message>
    <message>
        <source>Last Page</source>
        <translation>끝 쪽</translation>
    </message>
    <message>
        <source>Go to Page...</source>
        <translation>쪽 찾아가기...</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation></translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>확대</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation></translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>축소</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation></translation>
    </message>
    <message>
        <source>Fit to Window</source>
        <translation>창크기에 맞추기</translation>
    </message>
    <message>
        <source>Ctrl+3</source>
        <translation></translation>
    </message>
    <message>
        <source>Actual Size</source>
        <translation>실제 크기</translation>
    </message>
    <message>
        <source>Ctrl+1</source>
        <translation></translation>
    </message>
    <message>
        <source>Fit to Width</source>
        <translation>창너비에 맞추기</translation>
    </message>
    <message>
        <source>Ctrl+2</source>
        <translation></translation>
    </message>
    <message>
        <source>New</source>
        <translation>새 문서</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation></translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>열기...</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation></translation>
    </message>
    <message>
        <source>Close</source>
        <translation>닫기</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation></translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>실행 취소</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation></translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>다시 실행</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Z</source>
        <translation></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>잘라내기</translation>
    </message>
    <message>
        <source>Ctrl+X</source>
        <translation></translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>복사</translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation></translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>붙여넣기</translation>
    </message>
    <message>
        <source>Ctrl+V</source>
        <translation></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>지우기</translation>
    </message>
    <message>
        <source>Ctrl+Backspace</source>
        <translation></translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>환경 설정...</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>계단 모양</translation>
    </message>
    <message>
        <source>Tile</source>
        <translation>격자 모양</translation>
    </message>
    <message>
        <source>Go to Source</source>
        <translation>소스창으로 가기</translation>
    </message>
    <message>
        <source>Ctrl+&apos;</source>
        <translation></translation>
    </message>
    <message>
        <source>New from Template...</source>
        <translation>템플릿에서 새 문서...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation></translation>
    </message>
    <message>
        <source>Full Screen</source>
        <translation>전체 화면</translation>
    </message>
    <message>
        <source>Ctrl+Shift+F</source>
        <translation></translation>
    </message>
    <message>
        <source>Magnify</source>
        <translation>돋보기</translation>
    </message>
    <message>
        <source>Scroll</source>
        <translation>스크롤</translation>
    </message>
    <message>
        <source>Select Text</source>
        <translation>텍스트 선택</translation>
    </message>
    <message>
        <source>Select Image</source>
        <translation>그림 선택</translation>
    </message>
    <message>
        <source>Go to TeXworks home page</source>
        <translation>TeXworks 홈페이지 방문</translation>
    </message>
    <message>
        <source>Email to the mailing list</source>
        <translation>메일링리스트에 메일 보내기</translation>
    </message>
    <message>
        <source>Side by Side</source>
        <translation>나란히 두기</translation>
    </message>
    <message>
        <source>Place on Left</source>
        <translation>왼쪽에 두기</translation>
    </message>
    <message>
        <source>Place on Right</source>
        <translation>오른쪽에 두기</translation>
    </message>
    <message>
        <source>Quit TeXworks</source>
        <translation>TeXworks 종료</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation></translation>
    </message>
    <message>
        <source>Find...</source>
        <translation>찾기...</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation></translation>
    </message>
    <message>
        <source>Find Again</source>
        <translation>다시 찾기</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation></translation>
    </message>
    <message>
        <source>Typeset</source>
        <comment>menu title</comment>
        <translation>조판</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>스크립트</translation>
    </message>
    <message>
        <source>Scripting TeXworks</source>
        <translation>TeXworks 스크립트</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <comment>action</comment>
        <translation></translation>
    </message>
    <message>
        <source>Reload Script List</source>
        <translation>스크립트 목록 다시 읽기</translation>
    </message>
    <message>
        <source>Manage Scripts</source>
        <translation>스크립트 관리</translation>
    </message>
    <message>
        <source>Show Scripts Folder</source>
        <translation>스크립트 폴더 보기</translation>
    </message>
    <message>
        <source>About Scripts...</source>
        <translation>스크립트에 대하여...</translation>
    </message>
    <message>
        <source>Print Pdf...</source>
        <translation>PDF 인쇄...</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation></translation>
    </message>
    <message>
        <source>Abort typesetting</source>
        <translation>조판 중단</translation>
    </message>
    <message>
        <source>Unfortunately, this version of %1 is unable to print Pdf documents due to various technical reasons.
</source>
        <translation>아쉽게도 %1 현재 버전은 PDF 인쇄 기능이 없습니다.
</translation>
    </message>
    <message>
        <source>Do you want to open the file in the default viewer for printing instead?</source>
        <translation>대신에 기본 뷰어 프로그램으로 열어 인쇄하시겠습니까?</translation>
    </message>
    <message>
        <source> (remember to close it again to avoid access problems)</source>
        <translation> (프로그램간 권한 충돌이 있을 수 있으므로 인쇄 후 뷰어를 닫아주세요)</translation>
    </message>
    <message>
        <source>Settings and Resources...</source>
        <translation>설정과 자원...</translation>
    </message>
    <message>
        <source>Clear Recent Files</source>
        <translation>최근 목록 지우기</translation>
    </message>
    <message>
        <source>Error initializing SyncTeX</source>
        <translation>SyncTeX 초기화 실패</translation>
    </message>
    <message>
        <source>Go to previous view</source>
        <translation>이전으로 돌아가기</translation>
    </message>
    <message>
        <source>Alt+Left</source>
        <translation></translation>
    </message>
    <message>
        <source>Single Page</source>
        <translation>한 쪽씩 따로</translation>
    </message>
    <message>
        <source>Single Page Continuous</source>
        <translation>한 쪽씩 이어서</translation>
    </message>
    <message>
        <source>Two Pages Continuous</source>
        <translation>맞쪽 이어서</translation>
    </message>
    <message>
        <source>Jump to Source</source>
        <translation>소스의 여기로 가기</translation>
    </message>
    <message>
        <source>Go to Page</source>
        <translation>쪽 찾아가기</translation>
    </message>
    <message>
        <source>Page number:</source>
        <translation>쪽 번호:</translation>
    </message>
    <message>
        <source>Open URL</source>
        <translation>URL 열기</translation>
    </message>
    <message>
        <source>You are in the process of opening the URL %1. Opening unknown or untrusted web adresses can be a security risk.
Do you want to continue?</source>
        <translation>다음 URL을 열고자 합니다: %1. 신뢰할 수 없는 웹주소를 열면 보안이 위험해집니다. 계속하시겠습니까?</translation>
    </message>
    <message>
        <source>Custom...</source>
        <translation>사용자 설정...</translation>
    </message>
    <message>
        <source>Set Zoom</source>
        <translation>확대 설정</translation>
    </message>
    <message>
        <source>Zoom level:</source>
        <translation>확대 비율:</translation>
    </message>
</context>
<context>
    <name>PDFFindDialog</name>
    <message>
        <source>Find</source>
        <translation>찾기</translation>
    </message>
    <message>
        <source>No recent search strings</source>
        <translation>최근 찾기 문자열 없음</translation>
    </message>
    <message>
        <source>Find in PDF</source>
        <translation>PDF에서 찾기</translation>
    </message>
    <message>
        <source>Find:</source>
        <translation>찾을 문자열:</translation>
    </message>
    <message>
        <source>&amp;Wrap around</source>
        <translation>끝까지 가면 처음부터(&amp;w)</translation>
    </message>
    <message>
        <source>Find &amp;backwards</source>
        <translation>뒤로 찾기(&amp;b)</translation>
    </message>
    <message>
        <source>Find &amp;all occurrences</source>
        <translation>한꺼번에 찾기(&amp;a)</translation>
    </message>
    <message>
        <source>&amp;Case sensitive</source>
        <translation>대소문자 구분(&amp;c)</translation>
    </message>
    <message>
        <source>&amp;Sync to source</source>
        <translation>소스와 연동(&amp;s)</translation>
    </message>
</context>
<context>
    <name>PrefsDialog</name>
    <message>
        <source>Choose Directory</source>
        <translation>디렉토리 선택</translation>
    </message>
    <message>
        <source>New Tool</source>
        <translation>새 도구</translation>
    </message>
    <message>
        <source>System default [%1]</source>
        <translation>시스템 기본값 [%1]</translation>
    </message>
    <message>
        <source>None</source>
        <translation>없음</translation>
    </message>
    <message>
        <source>TeXworks Preferences</source>
        <translation>TeXworks 환경 설정</translation>
    </message>
    <message>
        <source>General</source>
        <translation>일반</translation>
    </message>
    <message>
        <source>Small icons</source>
        <translation>작은 아이콘</translation>
    </message>
    <message>
        <source>Medium icons</source>
        <translation>보통 아이콘</translation>
    </message>
    <message>
        <source>Large icons</source>
        <translation>큰 아이콘</translation>
    </message>
    <message>
        <source>Show text as well as icons</source>
        <translation>텍스트도 보여주기</translation>
    </message>
    <message>
        <source>When launched, show</source>
        <translation>처음 실행시 보이기</translation>
    </message>
    <message>
        <source>New blank document</source>
        <translation>새로운 빈 문서</translation>
    </message>
    <message>
        <source>Template selection dialog</source>
        <translation>템플릿 선택 대화상자</translation>
    </message>
    <message>
        <source>File Open dialog</source>
        <translation>파일 열기 대화상자</translation>
    </message>
    <message>
        <source>Editor</source>
        <translation>편집기</translation>
    </message>
    <message>
        <source>Editor defaults</source>
        <translation>편집기 기본값</translation>
    </message>
    <message>
        <source> pt</source>
        <translation>포인트</translation>
    </message>
    <message>
        <source>Tab width:</source>
        <translation>탭 크기:</translation>
    </message>
    <message>
        <source>Wrap lines</source>
        <translation>줄 넘김</translation>
    </message>
    <message>
        <source>Syntax coloring:</source>
        <translation>문법 강조:</translation>
    </message>
    <message>
        <source>Auto-Indent mode:</source>
        <translation>자동 들여쓰기 방식:</translation>
    </message>
    <message>
        <source>Spell-check language:</source>
        <translation>철자 검사 언어:</translation>
    </message>
    <message>
        <source>Encoding:</source>
        <translation>인코딩:</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>미리보기</translation>
    </message>
    <message>
        <source>Default scaling</source>
        <translation>확대 기본값</translation>
    </message>
    <message>
        <source>Actual size</source>
        <translation>실제 크기</translation>
    </message>
    <message>
        <source>Fit to Width</source>
        <translation>창너비에 맞추기</translation>
    </message>
    <message>
        <source>Fit to Window</source>
        <translation>창크기에 맞추기</translation>
    </message>
    <message>
        <source>Fixed scale:</source>
        <translation>고정 배율:</translation>
    </message>
    <message>
        <source> %</source>
        <translation></translation>
    </message>
    <message>
        <source>Magnifying glass</source>
        <translation>돋보기</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>작게</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>보통</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>크게</translation>
    </message>
    <message>
        <source>Circular magnifier</source>
        <translation>둥근 돋보기</translation>
    </message>
    <message>
        <source>Screen resolution:</source>
        <translation>화면 해상도:</translation>
    </message>
    <message>
        <source>Typesetting</source>
        <translation>문서처리</translation>
    </message>
    <message>
        <source>Paths for TeX and related programs</source>
        <translation>TeX 관련 프로그램 경로</translation>
    </message>
    <message>
        <source>Processing tools</source>
        <translation>문서처리 도구</translation>
    </message>
    <message>
        <source>Edit...</source>
        <translation>편집...</translation>
    </message>
    <message>
        <source>Default:</source>
        <translation>기본값:</translation>
    </message>
    <message>
        <source>Line numbers</source>
        <translation>줄번호 표시</translation>
    </message>
    <message>
        <source>Global editor options</source>
        <translation>편집기 옵션</translation>
    </message>
    <message>
        <source>Highlight current line</source>
        <translation>현재 줄 강조</translation>
    </message>
    <message>
        <source> px</source>
        <translation>픽셀</translation>
    </message>
    <message>
        <source>Smart Quotes mode:</source>
        <translation>똑똑한 인용부호 방식:</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>스크립트</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>보안</translation>
    </message>
    <message>
        <source>Allow scripts to read all files (script and document files are always readable)</source>
        <translation>모든 파일 읽기 허용 (스크립트 파일과 문서 파일은 항상 읽을 수 있음)</translation>
    </message>
    <message>
        <source>Allow scripts to write files</source>
        <translation>파일 쓰기 허용</translation>
    </message>
    <message>
        <source>Allow scripts to run system commands</source>
        <translation>시스템 명령 실행 허용</translation>
    </message>
    <message>
        <source>Enable plug-in scripting languages (may circumvent other restrictions on script behavior)</source>
        <translation>다른 스크립트 언어의 플러그인 허용 (스크립트에 대한 제약을 우회할 가능성 있음)</translation>
    </message>
    <message>
        <source>Debugging</source>
        <translation>디버깅</translation>
    </message>
    <message>
        <source>Enable QtScript debugger</source>
        <translation>Qt스크립트 디버거 활성화</translation>
    </message>
    <message>
        <source>Never</source>
        <extracomment>&quot;Hide console output&quot; mode</extracomment>
        <translation>안 함</translation>
    </message>
    <message>
        <source>Automatically</source>
        <extracomment>&quot;Hide console output&quot; mode</extracomment>
        <translation>자동으로</translation>
    </message>
    <message>
        <source>On success</source>
        <extracomment>&quot;Hide console output&quot; mode</extracomment>
        <translation>성공하면</translation>
    </message>
    <message>
        <source>&lt;em&gt;Note:&lt;/em&gt; These are default settings. Changes to them will not affect windows that are already open. Use the respective items in the &amp;quot;Format&amp;quot; menu to achieve that.</source>
        <translation>&lt;em&gt;주의:&lt;/em&gt; 이곳에서는 기본값을 설정합니다. 이미 열려 있는 창에는 효과가 없습니다. 열려 있는 창에 적용하려면 &amp;quot;모양&amp;quot; 메뉴 아래의 항목들을 이용하세요.</translation>
    </message>
    <message>
        <source>Enable autocompletion</source>
        <translation>자동완성 기능 사용</translation>
    </message>
    <message>
        <source>Hide console output:</source>
        <translation>콘솔 출력 숨기기:</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;strong&gt;Never:&lt;/strong&gt; Never hide the console output panel after typesetting.&lt;/p&gt;
&lt;p&gt;&lt;strong&gt;Automatically:&lt;/strong&gt; Hide the console output panel after successful typesetting, but only if it was hidden before.&lt;/p&gt;
&lt;p&gt;&lt;strong&gt;On Success:&lt;/strong&gt; Hide the console output panel after successful typesetting, regardless of its previous state.&lt;/p&gt;
</source>
        <translation>&lt;p&gt;&lt;strong&gt;안 함:&lt;/strong&gt; 조판이 끝나도 콘솔 출력 패널을 닫지 않습니다.&lt;/p&gt;
&lt;p&gt;&lt;strong&gt;자동으로:&lt;/strong&gt; 조판이 성공하면 콘솔 출력 패널을 닫습니다. 단, 컴파일 시작시 닫혀 있었어야 합니다.&lt;/p&gt;
&lt;p&gt;&lt;strong&gt;성공하면:&lt;/strong&gt; 조판이 성공하면 콘솔 출력 패널을 닫습니다. 컴파일 시작시 닫혀 있었는지 불문합니다.&lt;/p&gt;
</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>인터페이스</translation>
    </message>
    <message>
        <source>Locale:</source>
        <translation>언어:</translation>
    </message>
    <message>
        <source>Toolbar buttons:</source>
        <translation>툴바 단추:</translation>
    </message>
    <message>
        <source>Open corresponding PDF preview with TeX files</source>
        <translation>TeX 파일과 함께 PDF도 열기</translation>
    </message>
    <message>
        <source>Page mode:</source>
        <translation>쪽 보기 방식:</translation>
    </message>
    <message>
        <source>Single Page</source>
        <translation>한 쪽씩 따로</translation>
    </message>
    <message>
        <source>Single Page Continuous</source>
        <translation>한 쪽씩 이어서</translation>
    </message>
    <message>
        <source>Two Page Continuous</source>
        <translation>맞쪽 이어서</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>TeX documents (*.tex)</source>
        <translation>TeX 문서 (*.tex)</translation>
    </message>
    <message>
        <source>LaTeX documents (*.ltx)</source>
        <translation>LaTeX 문서 (*.ltx)</translation>
    </message>
    <message>
        <source>BibTeX databases (*.bib)</source>
        <translation>BibTeX 데이터 (*.bib)</translation>
    </message>
    <message>
        <source>Style files (*.sty)</source>
        <translation>스타일 파일 (*.sty)</translation>
    </message>
    <message>
        <source>Class files (*.cls)</source>
        <translation>클래스 파일 (*.cls)</translation>
    </message>
    <message>
        <source>Documented macros (*.dtx)</source>
        <translation>문서화된 매크로 (*.dtx)</translation>
    </message>
    <message>
        <source>Text files (*.txt)</source>
        <translation>텍스트 파일 (*.txt)</translation>
    </message>
    <message>
        <source>PDF documents (*.pdf)</source>
        <translation>PDF 문서 (*.pdf)</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>모든 파일</translation>
    </message>
    <message>
        <source>Log files (*.log *.blg)</source>
        <translation>로그 파일 (*.log *.blg)</translation>
    </message>
    <message>
        <source>Auxiliary files (*.aux *.toc *.lot *.lof *.nav *.out *.snm *.ind *.idx *.bbl *.brf)</source>
        <translation>부수 파일 (*.aux *.toc *.lot *.lof *.nav *.out *.snm *.ind *.idx *.bbl *.brf)</translation>
    </message>
</context>
<context>
    <name>ReplaceDialog</name>
    <message>
        <source>Replace</source>
        <translation>바꾸기</translation>
    </message>
    <message>
        <source>Replace All</source>
        <translation>모두 바꾸기</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>No recent search strings</source>
        <translation>최근 찾기 문자열 없음</translation>
    </message>
    <message>
        <source>No recent replacement strings</source>
        <translation>최근 바꾸기 문자열 없음</translation>
    </message>
    <message>
        <source>(invalid)</source>
        <translation>(유효하지 않음)</translation>
    </message>
    <message>
        <source>Replace:</source>
        <translation>찾을 문자열:</translation>
    </message>
    <message>
        <source>With:</source>
        <translation>바꿀 문자열:</translation>
    </message>
    <message>
        <source>&amp;Wrap around</source>
        <translation>끝까지 가면 처음부터(&amp;w)</translation>
    </message>
    <message>
        <source>Find &amp;backwards</source>
        <translation>뒤로 찾기(&amp;b)</translation>
    </message>
    <message>
        <source>Replace within &amp;selection</source>
        <translation>선택영역 내에서 바꾸기(&amp;s)</translation>
    </message>
    <message>
        <source>Replace in all &amp;open files</source>
        <translation>열린 파일 다 바꾸기(&amp;o)</translation>
    </message>
    <message>
        <source>&amp;Case sensitive</source>
        <translation>대소문자 구분(&amp;c)</translation>
    </message>
    <message>
        <source>W&amp;hole words</source>
        <translation>전체가 맞는 단어만(&amp;h)</translation>
    </message>
    <message>
        <source>&amp;Regular expression</source>
        <translation>정규표현식(&amp;r)</translation>
    </message>
</context>
<context>
    <name>ResourcesDialog</name>
    <message>
        <source>TeXworks Settings and Resources</source>
        <translation>TeXworks 설정과 자원</translation>
    </message>
    <message>
        <source>Storage Locations</source>
        <translation>저장 위치</translation>
    </message>
    <message>
        <source>Settings:</source>
        <translation>설정:</translation>
    </message>
    <message>
        <source>Resources:</source>
        <translation>자원:</translation>
    </message>
    <message>
        <source>Registry (%1)</source>
        <translation>레지스트리 (%1)</translation>
    </message>
</context>
<context>
    <name>ScreenCalibrationWidget</name>
    <message>
        <source>Drag the ruler or change the value to match real world lengths.
Common paper sizes are marked as well (you may need to resize the dialog window to see them).
Use the context menu to change the units.</source>
        <translation>실제 길이에 맞추려면 줄자를 드래그하거나 값을 변경하세요.
널리 쓰이는 용지 크기도 표시됩니다 (대화창 크기를 조정해야 할 수 있습니다).
단위를 변경하려면 오른쪽 버튼 메뉴를 이용하세요.</translation>
    </message>
    <message>
        <source> dpi</source>
        <extracomment>dots per inch</extracomment>
        <translation></translation>
    </message>
    <message>
        <source>DIN A4</source>
        <translation>A4</translation>
    </message>
    <message>
        <source>Letter</source>
        <translation>레터</translation>
    </message>
    <message>
        <source>cm</source>
        <extracomment>this refers to the length unit of centimeters</extracomment>
        <translation></translation>
    </message>
    <message>
        <source>in</source>
        <extracomment>this refers to the length unit of inches</extracomment>
        <translation></translation>
    </message>
</context>
<context>
    <name>ScriptManager</name>
    <message>
        <source>Manage Scripts</source>
        <translation>스크립트 관리</translation>
    </message>
    <message>
        <source>Standalone Scripts</source>
        <translation>독립형 스크립트</translation>
    </message>
    <message>
        <source>Hook Scripts</source>
        <translation>후킹형 스크립트</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>이름:</translation>
    </message>
    <message>
        <source>Context: </source>
        <translation>환경:</translation>
    </message>
    <message>
        <source>Description: </source>
        <translation>기능:</translation>
    </message>
    <message>
        <source>Author: </source>
        <translation>저자:</translation>
    </message>
    <message>
        <source>Version: </source>
        <translation>버전:</translation>
    </message>
    <message>
        <source>Shortcut: </source>
        <translation>단축키:</translation>
    </message>
    <message>
        <source>File: </source>
        <translation>파일:</translation>
    </message>
    <message>
        <source>Language: </source>
        <translation>언어:</translation>
    </message>
    <message>
        <source>Hook: </source>
        <translation>후킹:</translation>
    </message>
</context>
<context>
    <name>SearchResults</name>
    <message>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <source>File</source>
        <translation>파일</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>행</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>시작</translation>
    </message>
    <message>
        <source>End</source>
        <translation>끝</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>텍스트</translation>
    </message>
    <message>
        <source>Search Results</source>
        <translation>찾기 결과</translation>
    </message>
    <message>
        <source>Search Results - %1 (%2 found)</source>
        <translation>찾기 결과 - %1 (%2군데 발견)</translation>
    </message>
</context>
<context>
    <name>TWApp</name>
    <message>
        <source>File</source>
        <translation>파일</translation>
    </message>
    <message>
        <source>New</source>
        <translation>새 문서</translation>
    </message>
    <message>
        <source>New from Template...</source>
        <translation>템플릿에서 새 문서...</translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>환경 설정...</translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>열기...</translation>
    </message>
    <message>
        <source>Open Recent</source>
        <translation>최근 문서 열기</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>도움말</translation>
    </message>
    <message>
        <source>About </source>
        <translation>정보 </translation>
    </message>
    <message>
        <source>Go to TeXworks home page</source>
        <translation>TeXworks 홈페이지 방문</translation>
    </message>
    <message>
        <source>Email to the mailing list</source>
        <translation>메일링리스트에 메일 보내기</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation></translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation></translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation></translation>
    </message>
    <message>
        <source>&lt;p&gt;%1 is a simple environment for editing, typesetting, and previewing TeX documents.&lt;/p&gt;</source>
        <translation>&lt;p&gt;%1는 TeX 문서를 편집하고 조판하고 미리보기할 수 있는 심플한 환경을 제공합니다.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;br&gt;&lt;a href=&quot;http://poppler.freedesktop.org/&quot;&gt;Poppler&lt;/a&gt; PDF rendering library by Kristian H&amp;#xF8;gsberg, Albert Astals Cid and others.</source>
        <translation>&lt;br&gt;&lt;a href=&quot;http://poppler.freedesktop.org/&quot;&gt;Poppler&lt;/a&gt; PDF 렌더링 라이브러리는 Kristian H&amp;#xF8;gsberg, Albert Astals Cid 등이 제공합니다.</translation>
    </message>
    <message>
        <source>&lt;br&gt;Concept and resources from &lt;a href=&quot;http://www.uoregon.edu/~koch/texshop/&quot;&gt;TeXShop&lt;/a&gt; by Richard Koch.</source>
        <translation>&lt;br&gt;Richard Koch의 &lt;a href=&quot;http://www.uoregon.edu/~koch/texshop/&quot;&gt;TeXShop&lt;/a&gt;에서 아이디어와 리소스를 도움받았습니다.</translation>
    </message>
    <message>
        <source>&lt;br&gt;&lt;a href=&quot;http://itexmac.sourceforge.net/SyncTeX.html&quot;&gt;SyncTeX&lt;/a&gt; technology by J&amp;#xE9;r&amp;#xF4;me Laurens.</source>
        <translation>&lt;br&gt;&lt;a href=&quot;http://itexmac.sourceforge.net/SyncTeX.html&quot;&gt;SyncTeX&lt;/a&gt; 기술은 J&amp;#xE9;r&amp;#xF4;me Laurens가 제공했습니다.</translation>
    </message>
    <message>
        <source>&lt;br&gt;Some icons used are from the &lt;a href=&quot;http://tango.freedesktop.org/&quot;&gt;Tango Desktop Project&lt;/a&gt;.</source>
        <translation>&lt;br&gt;일부 아이콘은 &lt;a href=&quot;http://tango.freedesktop.org/&quot;&gt;Tango Desktop Project&lt;/a&gt;에서 가져왔습니다.</translation>
    </message>
    <message>
        <source>&lt;p&gt;%1 translation kindly contributed by %2.</source>
        <translation>&lt;p&gt;%1 번역은 %2이 제공했습니다.</translation>
    </message>
    <message>
        <source>[language name]</source>
        <translation>한국어</translation>
    </message>
    <message>
        <source>[translator&apos;s name/email]</source>
        <translation>Dohyun Kim&amp;lt;nomos@ktug.org&amp;gt;</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>%1에 대하여</translation>
    </message>
    <message>
        <source>Unable to access &quot;%1&quot;; perhaps your browser or mail application is not properly configured?</source>
        <translation>&quot;%1&quot;에 접근할 수 없습니다. 브라우저나 이메일 설정이 올바릅니까?</translation>
    </message>
    <message>
        <source>Unable to create window</source>
        <translation>창을 생성할 수 없습니다</translation>
    </message>
    <message>
        <source>Something is badly wrong; %1 was unable to create a document window. The application will now quit.</source>
        <translation>무언가 잘못되었군요. %1가 문서창을 생성할 수 없습니다. 프로그램을 종료합니다.</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>파일 열기</translation>
    </message>
    <message>
        <source>No default binary directory found</source>
        <translation>기본 바이너리 디렉토리를 찾을 수 없습니다</translation>
    </message>
    <message>
        <source>None of the predefined directories for TeX-related programs could be found.&lt;p&gt;&lt;small&gt;To run any processes, you will need to set the binaries directory (or directories) for your TeX distribution using the Typesetting tab of the Preferences dialog.&lt;/small&gt;</source>
        <translation>TeX 관련 프로그램의 경로를 찾을 수 없습니다.&lt;p&gt;&lt;small&gt;문서처리를 위해서는 TeX 배포판의 바이너리 디렉토리를 환경 설정 대화상자의 문서처리 탭에서 설정해야 합니다.&lt;/small&gt;</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>파일 저장</translation>
    </message>
    <message>
        <source>Unable to find help file.</source>
        <translation>도움말 파일을 찾을 수 없습니다.</translation>
    </message>
    <message>
        <source>Permission request</source>
        <translation>권한 요청</translation>
    </message>
    <message>
        <source>The script &quot;%1&quot; is trying to open the file &quot;%2&quot; without sufficient permissions. Do you want to open the file?</source>
        <translation>&quot;%1&quot; 스크립트가 &quot;%2&quot; 파일을 열고자 하지만 권한이 없습니다. 그래도 파일을 열겠습니까?</translation>
    </message>
    <message>
        <source>&lt;p&gt;Distributed under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl-2.0.html&quot;&gt;GNU General Public License&lt;/a&gt;, version 2 or (at your option) any later version.</source>
        <translation>&lt;p&gt;&lt;a href=&quot;http://www.gnu.org/licenses/gpl-2.0.html&quot;&gt;GNU 일반 공중 허가서&lt;/a&gt; 제2판 또는 이후 버전들 중에서 라이선스를 선택하실 수 있습니다.</translation>
    </message>
    <message>
        <source>Clear Recent Files</source>
        <translation>최근 목록 지우기</translation>
    </message>
    <message>
        <source>&lt;br&gt;Version %1 (%2) [r.%3, %4]</source>
        <translation>&lt;br&gt;버전 %1 (%2) [r.%3, %4]</translation>
    </message>
    <message>
        <source>&lt;br&gt;Version %1 (%2)</source>
        <translation>&lt;br&gt;버전 %1 (%2)</translation>
    </message>
    <message>
        <source>Quit TeXworks</source>
        <translation>TeXworks 종료</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;a href=&quot;http://www.qt.io/&quot;&gt;Qt application framework&lt;/a&gt; v%1 by The Qt Company.</source>
        <translation>&lt;p&gt;&lt;a href=&quot;http://www.qt.io/&quot;&gt;Qt 응용 프레임워크&lt;/a&gt; v%1은(는) The Qt Company가 제공합니다.</translation>
    </message>
    <message>
        <source>&lt;br&gt;&lt;a href=&quot;http://hunspell.github.io/&quot;&gt;Hunspell&lt;/a&gt; spell checker by L&amp;#xE1;szl&amp;#xF3; N&amp;#xE9;meth.</source>
        <translation>&lt;br&gt;&lt;a href=&quot;http://hunspell.github.io/&quot;&gt;Hunspell&lt;/a&gt; 철자검사기는 L&amp;#xE1;szl&amp;#xF3; N&amp;#xE9;meth가 제공합니다.</translation>
    </message>
</context>
<context>
    <name>TWScriptAPI</name>
    <message>
        <source>Internal error</source>
        <translation>내부 오류</translation>
    </message>
    <message>
        <source>Failed to execute system command: %1</source>
        <translation>%1 시스템 명령 실행에 실패</translation>
    </message>
    <message>
        <source>Error executing system command: %1</source>
        <translation>%1 시스템 명령 실행에 오류 발생</translation>
    </message>
    <message>
        <source>System command execution is disabled (see Preferences)</source>
        <translation>시스템 명령 실행이 허용되지 않았습니다 (환경 설정을 확인하세요)</translation>
    </message>
    <message>
        <source>&quot;%1&quot; could not be opened.</source>
        <translation>&quot;%1&quot; 파일을 열 수 없습니다.</translation>
    </message>
    <message>
        <source>Reading all files is disabled (see Preferences)</source>
        <translation>모든 파일 읽기가 허용되지 않았습니다 (환경 설정을 확인하세요)</translation>
    </message>
    <message>
        <source>The file &quot;%1&quot; could not be opened for reading</source>
        <translation>&quot;%1&quot; 파일을 읽어들일 수 없음</translation>
    </message>
</context>
<context>
    <name>TWScriptable</name>
    <message>
        <source>Script &quot;%1&quot;: %2</source>
        <translation>스크립트 &quot;%1&quot;: %2</translation>
    </message>
    <message>
        <source>Script result</source>
        <translation>스크립트 수행 결과</translation>
    </message>
    <message>
        <source>unknown error</source>
        <translation>알 수 없는 오류</translation>
    </message>
    <message>
        <source>Scripts may be used to add new commands to %1, and to extend or modify its behavior.</source>
        <translation>스크립트를 이용해서 %1에 새로운 명령을 더하거나 기능을 확장하고 변경할 수 있습니다.</translation>
    </message>
    <message>
        <source>For more information on creating and using scripts, see %1&lt;/p&gt;</source>
        <translation>스크립트의 작성과 이용에 대해 상세한 것은 이 사이트를 참조하세요: %1&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Scripting languages currently available in this copy of %1:</source>
        <translation>설치된 %1에서 사용할 수 있는 스크립트 언어는 아래와 같습니다:</translation>
    </message>
    <message>
        <source>About Scripts</source>
        <translation>스크립트에 대하여</translation>
    </message>
    <message>
        <source>Script error</source>
        <translation>스크립트 오류</translation>
    </message>
    <message>
        <source>(disabled in the preferences)</source>
        <extracomment>This string is appended to a script language name to indicate it is currently disabled</extracomment>
        <translation>(환경설정에서 꺼져 있음)</translation>
    </message>
</context>
<context>
    <name>TWSystemCmd</name>
    <message>
        <source>ERROR: failure code %1</source>
        <translation>오류: 오류 코드 %1</translation>
    </message>
    <message>
        <source>ERROR: exit code %1</source>
        <translation>오류: 종료 코드 %1</translation>
    </message>
</context>
<context>
    <name>TagsDock</name>
    <message>
        <source>Tags</source>
        <translation>태그</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>북마크</translation>
    </message>
    <message>
        <source>Outline</source>
        <translation>개요</translation>
    </message>
    <message>
        <source>No tags</source>
        <translation>태그 없음</translation>
    </message>
</context>
<context>
    <name>TeXDocument</name>
    <message>
        <source>New document</source>
        <translation>새 문서</translation>
    </message>
    <message>
        <source>Open Recent</source>
        <translation>최근 문서 열기</translation>
    </message>
    <message>
        <source>None</source>
        <translation>없음</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>파일 열기</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>파일 저장</translation>
    </message>
    <message>
        <source>The document &quot;%1&quot; has been modified.
Do you want to save your changes?</source>
        <translation>&quot;%1&quot; 문서가 변경되었습니다. 저장하시겠습니까?</translation>
    </message>
    <message>
        <source>Do you want to discard all changes to the document &quot;%1&quot;, and revert to the last saved version?</source>
        <translation>&quot;%1&quot; 문서의 변경된 내용을 버리고 최근 저장 상태로 복구하시겠습니까?</translation>
    </message>
    <message>
        <source>Revert</source>
        <translation>복구</translation>
    </message>
    <message>
        <source>Unrecognized encoding</source>
        <translation>알 수 없는 인코딩</translation>
    </message>
    <message>
        <source>The text encoding %1 used in %2 is not supported.

It will be interpreted as %3 instead, which may result in incorrect text.</source>
        <translation>%2에 사용된 %1 인코딩은 지원되지 않는 인코딩입니다.

대신 %3 인코딩으로 읽겠습니다. 글자가 깨질 수 있습니다.</translation>
    </message>
    <message>
        <source>File changed on disk</source>
        <translation>디스크에서 파일이 변경되었습니다</translation>
    </message>
    <message>
        <source>%1 has been modified by another program.

Do you want to discard your current changes, and reload the file from disk?</source>
        <translation>다른 프로그램이 %1 파일을 변경했습니다.

작업한 것을 버리고 디스크에서 파일을 읽어오겠습니까?</translation>
    </message>
    <message>
        <source>%1 has been modified by another program.

Do you want to proceed with saving this file, overwriting the version on disk?</source>
        <translation>다른 프로그램이 %1 파일을 변경했습니다.

디스크의 파일을 덮어쓰게 되는데 그래도 저장하시겠습니까?</translation>
    </message>
    <message>
        <source>Document &quot;%1&quot; was not saved</source>
        <translation>&quot;%1&quot; 문서가 저장되지 않았습니다</translation>
    </message>
    <message>
        <source>Text cannot be converted</source>
        <translation>텍스트를 변환할 수 없습니다</translation>
    </message>
    <message>
        <source>This document contains characters that cannot be represented in the encoding %1.

If you proceed, they will be replaced with default codes. Alternatively, you may wish to use a different encoding (such as UTF-8) to avoid loss of data.</source>
        <translation>문서가 %1 인코딩에 속하지 않는 글자를 가지고 있습니다.

계속 진행하면 이 글자들은 기본 코드로 대체됩니다. 데이터 손실을 막으려면 다른 인코딩(예: UTF-8)으로 저장하십시오.</translation>
    </message>
    <message>
        <source>untitled-%1.tex</source>
        <translation></translation>
    </message>
    <message>
        <source>%1[*] - %2</source>
        <translation></translation>
    </message>
    <message>
        <source>Line %1 of %2; col %3</source>
        <translation>%2행 중 %1행, %3열</translation>
    </message>
    <message>
        <source>Go to Line</source>
        <translation>줄 찾아 가기</translation>
    </message>
    <message>
        <source>Line number:</source>
        <translation>줄 번호:</translation>
    </message>
    <message>
        <source>Invalid regular expression</source>
        <translation>잘못된 정규표현식</translation>
    </message>
    <message>
        <source>Not found</source>
        <translation>없음</translation>
    </message>
    <message numerus="yes">
        <source>Found %n occurrence(s)</source>
        <translation>
            <numerusform>%n군데 찾음</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n occurrence(s)</source>
        <translation>
            <numerusform>%n군데</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n documents</source>
        <translation>
            <numerusform>%n개의 문서</numerusform>
        </translation>
    </message>
    <message>
        <source>Replaced %1 in %2</source>
        <translation>%2군데 중 %1군데 바꿈</translation>
    </message>
    <message numerus="yes">
        <source>Replaced %n occurrence(s)</source>
        <translation>
            <numerusform>%n군데 바꿈</numerusform>
        </translation>
    </message>
    <message>
        <source>Cannot process unsaved document</source>
        <translation>저장하지 않은 문서는 처리할 수 없습니다</translation>
    </message>
    <message>
        <source>Root document %1 is not readable</source>
        <translation>메인 문서 %1을 읽을 수 없습니다</translation>
    </message>
    <message>
        <source>%1 is not properly configured</source>
        <translation>%1은 설정이 잘못되었습니다</translation>
    </message>
    <message>
        <source>Unable to execute %1</source>
        <translation>%1을 실행할 수 없습니다</translation>
    </message>
    <message>
        <source>Set engine to &quot;%1&quot;</source>
        <translation>엔진을 &quot;%1&quot;으로 지정</translation>
    </message>
    <message>
        <source>Engine &quot;%1&quot; not defined</source>
        <translation>&quot;%1&quot; 엔진이 지정되지 않았습니다</translation>
    </message>
    <message>
        <source>No files found</source>
        <translation>파일 없음</translation>
    </message>
    <message>
        <source>No auxiliary files associated with this document at the moment.</source>
        <translation>이 문서는 부수파일이 없습니다.</translation>
    </message>
    <message>
        <source>untitled.tex[*]</source>
        <translation></translation>
    </message>
    <message>
        <source>File</source>
        <translation>파일</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>편집</translation>
    </message>
    <message>
        <source>Spelling</source>
        <translation>철자 검사</translation>
    </message>
    <message>
        <source>Change Case</source>
        <translation>대소문자 변경</translation>
    </message>
    <message>
        <source>Typeset</source>
        <translation>조판</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>창</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>보기</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>찾기</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>모양</translation>
    </message>
    <message>
        <source>Auto-indent Mode</source>
        <translation>자동 들여쓰기</translation>
    </message>
    <message>
        <source>Syntax Coloring</source>
        <translation>문법 강조</translation>
    </message>
    <message>
        <source>Smart Quotes</source>
        <translation>똑똑한 인용부호</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>도움말</translation>
    </message>
    <message>
        <source>Typeset Toolbar</source>
        <translation>조판 툴바</translation>
    </message>
    <message>
        <source>Edit Toolbar</source>
        <translation>편집 툴바</translation>
    </message>
    <message>
        <source>New</source>
        <translation>새 문서</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation></translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>열기...</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation></translation>
    </message>
    <message>
        <source>Close</source>
        <translation>닫기</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation></translation>
    </message>
    <message>
        <source>Save</source>
        <translation>저장</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation></translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation>다른 이름으로 저장...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+S</source>
        <translation></translation>
    </message>
    <message>
        <source>Revert to Saved</source>
        <translation>저장된 버전으로 복구</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>실행 취소</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation></translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>다시 실행</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Z</source>
        <translation></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>잘라내기</translation>
    </message>
    <message>
        <source>Ctrl+X</source>
        <translation></translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>복사</translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation></translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>붙여넣기</translation>
    </message>
    <message>
        <source>Ctrl+V</source>
        <translation></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>지우기</translation>
    </message>
    <message>
        <source>Find...</source>
        <translation>찾기...</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation></translation>
    </message>
    <message>
        <source>Find Again</source>
        <translation>다시 찾기</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation></translation>
    </message>
    <message>
        <source>Replace...</source>
        <translation>바꾸기...</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation></translation>
    </message>
    <message>
        <source>Copy to Find</source>
        <translation>찾기 상자에 복사</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation></translation>
    </message>
    <message>
        <source>Copy to Replace</source>
        <translation>바꾸기 상자에 복사</translation>
    </message>
    <message>
        <source>Ctrl+Shift+E</source>
        <translation></translation>
    </message>
    <message>
        <source>Go to Line...</source>
        <translation>줄 찾아 가기...</translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation></translation>
    </message>
    <message>
        <source>Find Selection</source>
        <translation>선택 문자열로 찾기</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation></translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>모두 선택</translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation></translation>
    </message>
    <message>
        <source>Font...</source>
        <translation>글꼴...</translation>
    </message>
    <message>
        <source>Indent</source>
        <translation>들여쓰기</translation>
    </message>
    <message>
        <source>Ctrl+]</source>
        <translation></translation>
    </message>
    <message>
        <source>Unindent</source>
        <translation>내어쓰기</translation>
    </message>
    <message>
        <source>Ctrl+[</source>
        <translation></translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>주석달기</translation>
    </message>
    <message>
        <source>Ctrl+Shift+]</source>
        <translation></translation>
    </message>
    <message>
        <source>Uncomment</source>
        <translation>주석풀기</translation>
    </message>
    <message>
        <source>Ctrl+Shift+[</source>
        <translation></translation>
    </message>
    <message>
        <source>Wrap Lines</source>
        <translation>줄 넘김</translation>
    </message>
    <message>
        <source>About TeXworks...</source>
        <translation>TeXworks에 대하여...</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>계단 모양</translation>
    </message>
    <message>
        <source>Tile</source>
        <translation>격자 모양</translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>환경 설정...</translation>
    </message>
    <message>
        <source>Go to Preview</source>
        <translation>미리보기 창으로 가기</translation>
    </message>
    <message>
        <source>Ctrl+&apos;</source>
        <translation></translation>
    </message>
    <message>
        <source>Ctrl+\</source>
        <translation></translation>
    </message>
    <message>
        <source>New from Template...</source>
        <translation>템플릿에서 새 문서...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation></translation>
    </message>
    <message>
        <source>Show Selection</source>
        <translation>선택 영역 보기</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation></translation>
    </message>
    <message>
        <source>ALL UPPERCASE</source>
        <translation>모두 대문자</translation>
    </message>
    <message>
        <source>all lowercase</source>
        <translation>모두 소문자</translation>
    </message>
    <message>
        <source>Balance Delimiters</source>
        <translation>괄호 범위 선택</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation></translation>
    </message>
    <message>
        <source>Go to TeXworks home page</source>
        <translation>TeXworks 홈페이지 방문</translation>
    </message>
    <message>
        <source>Email to the mailing list</source>
        <translation>메일링리스트에 메일 보내기</translation>
    </message>
    <message>
        <source>Side by Side</source>
        <translation>나란히 두기</translation>
    </message>
    <message>
        <source>Place on Left</source>
        <translation>왼쪽에 두기</translation>
    </message>
    <message>
        <source>Place on Right</source>
        <translation>오른쪽에 두기</translation>
    </message>
    <message>
        <source>Replace Again</source>
        <translation>다시 바꾸기</translation>
    </message>
    <message>
        <source>Ctrl+Shift+R</source>
        <translation></translation>
    </message>
    <message>
        <source>Remove Aux Files...</source>
        <translation>부수파일 삭제...</translation>
    </message>
    <message>
        <source>Quit TeXworks</source>
        <translation>TeXworks 종료</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation></translation>
    </message>
    <message>
        <source>Toggle Case</source>
        <translation>대소문자 맞바꾸기</translation>
    </message>
    <message>
        <source>The program &quot;%1&quot; was not found.</source>
        <translation>&quot;%1&quot; 프로그램을 찾을 수 없습니다.</translation>
    </message>
    <message>
        <source>Searched in directories:</source>
        <translation>다음 디렉토리를 검색했습니다:</translation>
    </message>
    <message>
        <source>Hard Wrap...</source>
        <translation>자동 줄 바꿈...</translation>
    </message>
    <message>
        <source>Line Numbers</source>
        <translation>줄번호 표시</translation>
    </message>
    <message>
        <source>Console output</source>
        <translation>콘솔 출력</translation>
    </message>
    <message>
        <source>Typeset</source>
        <comment>menu title</comment>
        <translation>조판</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>스크립트</translation>
    </message>
    <message>
        <source>Scripting TeXworks</source>
        <translation>TeXworks 스크립트</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <comment>action</comment>
        <translation></translation>
    </message>
    <message>
        <source>Show Scripts Folder</source>
        <translation>스크립트 폴더 보기</translation>
    </message>
    <message>
        <source>Reload Script List</source>
        <translation>스크립트 목록 다시 읽기</translation>
    </message>
    <message>
        <source>Manage Scripts</source>
        <translation>스크립트 관리</translation>
    </message>
    <message>
        <source>Auto-Follow Focus</source>
        <translation>위치 자동 따라가기</translation>
    </message>
    <message>
        <source>About Scripts...</source>
        <translation>스크립트에 대하여...</translation>
    </message>
    <message>
        <source>Apply to Selection</source>
        <translation>선택 영역에 적용</translation>
    </message>
    <message>
        <source>Save All</source>
        <translation>모두 저장</translation>
    </message>
    <message>
        <source>Ctrl+Alt+S</source>
        <translation></translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <comment>shortcut: Don&apos;t Save</comment>
        <translation></translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <comment>shortcut: Revert</comment>
        <translation></translation>
    </message>
    <message>
        <source>Cannot read file &quot;%1&quot;:
%2</source>
        <translation>&quot;%1&quot; 파일을 읽을 수 없습니다:
%2</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; loaded</source>
        <translation>&quot;%1&quot; 파일을 읽어들임</translation>
    </message>
    <message>
        <source>%1 is constantly being modified by another program.

Please use &quot;File &gt; Revert to Saved&quot; manually when the external process has finished.</source>
        <translation>다른 프로그램이 %1 파일을 변경하고 있습니다.

외부 프로세스가 끝나면 수동으로 &quot;파일-&gt;저장된 버전으로 복구&quot;를 수행하세요.</translation>
    </message>
    <message>
        <source>Cannot write file &quot;%1&quot;:
%2</source>
        <translation>&quot;%1&quot; 파일을 저장할 수 없습니다:
%2</translation>
    </message>
    <message>
        <source>Error writing file</source>
        <translation>파일 저장 오류</translation>
    </message>
    <message>
        <source>An error may have occurred while saving the file. You might like to save a copy in a different location.</source>
        <translation>파일 저장 중에 오류가 발생했습니다. 다른 장소에 사본을 저장하시기 바랍니다.</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; saved</source>
        <translation>&quot;%1&quot; 파일 저장됨</translation>
    </message>
    <message>
        <source>Abort typesetting</source>
        <translation>조판 중단</translation>
    </message>
    <message>
        <source>Process interrupted by user</source>
        <translation>사용자가 프로세스를 중단했습니다</translation>
    </message>
    <message>
        <source>Settings and Resources...</source>
        <translation>설정과 자원...</translation>
    </message>
    <message>
        <source>Reload using selected encoding</source>
        <extracomment>Item in the encoding popup menu</extracomment>
        <translation>선택된 인코딩을 써서 다시 읽기</translation>
    </message>
    <message>
        <source>Reloads the current file with the encoding selected from this menu.

The selected encoding replaces the default one and overrides all &quot;%!TEX encoding&quot; lines.</source>
        <extracomment>Tooltip for &quot;Reload using selected encoding&quot;</extracomment>
        <translation>현재 파일의 인코딩을 메뉴에서 선택한 것으로 바꿉니다.

기본값이나 &quot;%!TEX-encoding&quot; 줄은 무시되고 선택된 인코딩을 적용합니다.</translation>
    </message>
    <message>
        <source>Unsaved changes</source>
        <translation>변경사항이 저장되지 않음</translation>
    </message>
    <message>
        <source>The file you are trying to reload has unsaved changes.

Do you want to discard your current changes, and reload the file from disk with the encoding %1?</source>
        <translation>다시 읽어들이려는 파일의 일부 변경사항이 저장되지 않았습니다.

변경사항을 버리고 새로운 인코딩 %1(으)로 다시 불러오겠습니까?</translation>
    </message>
    <message>
        <source>Clear Recent Files</source>
        <translation>최근 목록 지우기</translation>
    </message>
    <message>
        <source>Abort typesetting?</source>
        <translation>조판을 중단할까요?</translation>
    </message>
    <message>
        <source>A typesetting process is still running and must be stopped before closing this window.
Do you want to stop it now?</source>
        <translation>조판이 진행 중입니다. 창을 닫기 전에 중단해야 합니다. 지금 조판을 중단할까요?</translation>
    </message>
    <message>
        <source>You need a &lt;b&gt;TeX distribution&lt;/b&gt; like &lt;a href=&quot;http://tug.org/texlive/&quot;&gt;TeX Live&lt;/a&gt; or &lt;a href=&quot;http://miktex.org/&quot;&gt;MiKTeX&lt;/a&gt; installed on your system to typeset your document.</source>
        <translation>문서를 조판하기 위해서는 &lt;a href=&quot;http://tug.org/texlive/&quot;&gt;TeX Live&lt;/a&gt;나 &lt;a href=&quot;http://miktex.org/&quot;&gt;MiKTeX&lt;/a&gt; 같은 &lt;b&gt;텍배포판&lt;/b&gt;이 설치돼 있어야 합니다.</translation>
    </message>
    <message>
        <source>You need a &lt;b&gt;TeX distribution&lt;/b&gt; like &lt;a href=&quot;http://www.tug.org/mactex/&quot;&gt;MacTeX&lt;/a&gt; installed on your system to typeset your document.</source>
        <translation>문서를 조판하기 위해서는 &lt;a href=&quot;http://www.tug.org/mactex/&quot;&gt;MacTeX&lt;/a&gt; 같은 &lt;b&gt;텍배포판&lt;/b&gt;이 설치돼 있어야 합니다.</translation>
    </message>
    <message>
        <source>You need a &lt;b&gt;TeX distribution&lt;/b&gt; like &lt;a href=&quot;http://tug.org/texlive/&quot;&gt;TeX Live&lt;/a&gt; installed on your system to typeset your document. On most systems such a TeX distribution is available as prebuilt package.</source>
        <translation>문서를 조판하기 위해서는 &lt;a href=&quot;http://tug.org/texlive/&quot;&gt;TeX Live&lt;/a&gt; 같은 &lt;b&gt;텍배포판&lt;/b&gt;이 설치돼 있어야 합니다. 텍배포판은 완성된 패키지 형태로 제공되는 것이 보통입니다.</translation>
    </message>
    <message>
        <source>When a TeX distribution is installed you may need to tell TeXworks where to find it in Edit -&gt; Preferences -&gt; Typesetting.</source>
        <translation>텍배포판이 설치돼 있다면 TeXworks의 편집 -&gt; 환경 설정 -&gt; 문서처리 탭에서 그 경로를 지정할 필요가 있습니다.</translation>
    </message>
    <message>
        <source>Check the configuration of the %1 tool and the path settings in the Preferences dialog.</source>
        <translation>환경 설정 대화상자에서 %1 도구와 경로 설정을 확인하세요.</translation>
    </message>
    <message>
        <source>Hide Console Output</source>
        <translation>콘솔 출력 숨기기</translation>
    </message>
    <message>
        <source>Layout Problem</source>
        <translation>레이아웃 문제</translation>
    </message>
    <message>
        <source>A problem occured while laying out the loaded document in the editor. This is caused by an issue in the underlying Qt framework and can cause TeXworks to crash under certain circumstances. The symptoms of this problem are hidden or overlapping lines. To work around this, please try one of the following:
 -) Turn syntax highlighting off and on
 -) Turn line numbers off and on
 -) Resize the window

We are sorry for the inconvenience.</source>
        <translation>불러온 문서를 편집기에 레이아웃하는 데 문제가 발생했습니다. Qt 프레임워크에서 발생한 문제로서 TeXworks가 죽는 원인이 될 수도 있습니다. 증상은 일부 행이 보이지 않거나 겹쳐 보이는 것입니다. 이 문제를 피하려면 다음 중 하나를 시도하십시오:
 -) 문법 강조를 껐다가 켭니다
 -) 줄 번호 표시를 껐다가 켭니다
 -) 창 크기를 조절합니다

불편을 드려 죄송합니다.</translation>
    </message>
    <message>
        <source>Show Console Output</source>
        <translation>콘솔 출력 보기</translation>
    </message>
    <message>
        <source>Write UTF-8 byte order mark</source>
        <translation>UTF-8 BOM (byte order mark) 넣기</translation>
    </message>
</context>
<context>
    <name>TeXHighlighter</name>
    <message>
        <source>default</source>
        <translation>기본값</translation>
    </message>
</context>
<context>
    <name>TemplateDialog</name>
    <message>
        <source>New File using Template</source>
        <translation>템플릿에서 새 문서</translation>
    </message>
    <message>
        <source>Choose template for the new document:</source>
        <translation>새 문서에 쓸 템플릿 선택:</translation>
    </message>
</context>
<context>
    <name>ToolConfig</name>
    <message>
        <source>NewArgument</source>
        <translation>새로운인자</translation>
    </message>
    <message>
        <source>Select program file</source>
        <translation>프로그램 파일 선택</translation>
    </message>
    <message>
        <source>Invalid program</source>
        <translation>유효하지 않은 프로그램</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; is not executable!</source>
        <translation>&apos;%1&apos; 파일은 실행할 수 없습니다!</translation>
    </message>
</context>
<context>
    <name>ToolConfigDialog</name>
    <message>
        <source>Tool Configuration</source>
        <translation>도구 설정</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>이름:</translation>
    </message>
    <message>
        <source>Program:</source>
        <translation>프로그램:</translation>
    </message>
    <message>
        <source>Arguments:</source>
        <translation>인자:</translation>
    </message>
    <message>
        <source>View PDF after running</source>
        <translation>문서처리 후 PDF 보기</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>둘러보기...</translation>
    </message>
</context>
</TS>
